from countershape import Page

pages = [
    Page("anticache.html", "Anticache"),
    Page("clientreplay.html", "Client-side replay"),
    Page("filters.html", "Filter expressions"),
    Page("passthrough.html", "Ignore Domains"),
    Page("proxyauth.html", "Proxy Authentication"),
    Page("replacements.html", "Replacements"),
    Page("responsestreaming.html", "Response Streaming"),
    Page("reverseproxy.html", "Reverse proxy mode"),
    Page("socksproxy.html", "SOCKS Mode"),
    Page("setheaders.html", "Set Headers"),
    Page("serverreplay.html", "Server-side replay"),
    Page("sticky.html", "Sticky cookies and auth"),
    Page("tcpproxy.html", "TCP Proxy"),
    Page("upstreamcerts.html", "Upstream Certs"),
    Page("upstreamproxy.html", "Upstream proxy mode"),
]